==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/FormatRadialGaugeLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatRadialGaugeLabelEventArgsDescription } from "./FormatRadialGaugeLabelEventArgsDescription";
/**
 * @hidden
 */
var FormatRadialGaugeLabelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatRadialGaugeLabelEventArgsDescriptionMetadata, _super);
    function FormatRadialGaugeLabelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.b = function (a) {
        if (FormatRadialGaugeLabelEventArgsDescriptionMetadata.a == null) {
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.c(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
        if (a.g(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.c = function (a) {
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.d = function (a) {
        FormatRadialGaugeLabelEventArgsDescriptionMetadata.b(a);
        a.u("FormatRadialGaugeLabelEventArgs", function () { return new FormatRadialGaugeLabelEventArgsDescription(); });
        a.t("FormatRadialGaugeLabelEventArgs", FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.$t = markType(FormatRadialGaugeLabelEventArgsDescriptionMetadata, 'FormatRadialGaugeLabelEventArgsDescriptionMetadata');
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.a = null;
    return FormatRadialGaugeLabelEventArgsDescriptionMetadata;
}(Base));
export { FormatRadialGaugeLabelEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FormatRadialGaugeLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatRadialGaugeLabelEventArgsDescription } from "./FormatRadialGaugeLabelEventArgsDescription";
/**
 * @hidden
 */
var FormatRadialGaugeLabelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatRadialGaugeLabelEventArgsDescriptionMetadata, _super);
    function FormatRadialGaugeLabelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.b = function (a) {
        if (FormatRadialGaugeLabelEventArgsDescriptionMetadata.a == null) {
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.c(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
        if (a.j(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.c = function (a) {
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.d = function (a) {
        FormatRadialGaugeLabelEventArgsDescriptionMetadata.b(a);
        a.aa("FormatRadialGaugeLabelEventArgs", function () { return new FormatRadialGaugeLabelEventArgsDescription(); });
        a.z("FormatRadialGaugeLabelEventArgs", FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.$t = markType(FormatRadialGaugeLabelEventArgsDescriptionMetadata, 'FormatRadialGaugeLabelEventArgsDescriptionMetadata');
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.a = null;
    return FormatRadialGaugeLabelEventArgsDescriptionMetadata;
}(Base));
export { FormatRadialGaugeLabelEventArgsDescriptionMetadata };
